@@ -12,7 +12,7 @@ use English qw( -no_match_vars );
 use DirHandle();
 use POSIX();
 
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 sub _SIZE_OF_TZ_HEADER                     { return 44 }
 sub _SIZE_OF_TRANSITION_TIME_V1            { return 4 }
@@ -1254,7 +1254,7 @@ sub _read_tz_definition {
 
 sub _parse_tz_variable {
     my ( $self, $tz_variable, $path ) = @_;
-    my $timezone_abbr_name_regex = qr/[^:\d,+-][^\d,+-]{2,}/smx;
+    my $timezone_abbr_name_regex = qr/(?:[^:\d,+-][^\d,+-]{2,}|[<][+-]?\d+[>])/smx;
     my $std_name_regex           = qr/(?<std_name>$timezone_abbr_name_regex)/smx
       ;    # Name for standard offset from GMT
     my $std_sign_regex    = qr/(?<std_sign>[+-])/smx;
@@ -1549,7 +1549,7 @@ Time::Zone::Olson - Provides an interface to the Olson timezone database
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
